@@ -35,8 +35,8 @@ fn point_overlays() {
   let p1 = Point::new(1, 2);
   let p2 = Point::new(1, 2);
   let p3 = Point::new(2, 1);
-  assert_eq!(p2.overlays(p1), true);
-  assert_eq!(p3.overlays(p2), false);
+  assert!(p2.overlays(p1));
+  assert!(!p3.overlays(p2));
 }
 
 #[test]
